@@ -2,6 +2,7 @@
 # The MIT License (MIT)
 #
 # Copyright © 2014 Tim Bielawa <timbielawa@gmail.com>
+# See GitHub Contributors Graph for more information
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -33,6 +34,7 @@ decimal and binary prefixes:
 man 7 units (from the Linux Documentation Project 'man-pages' package)
 """
 
+from __future__ import print_function
 
 import contextlib
 import fnmatch
@@ -45,7 +47,7 @@ import sys
 __all__ = [
     'Bit', 'Byte', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB',
     'Kib', 'Mib', 'Gib', 'Tib', 'Pib', 'Eib', 'kb', 'Mb', 'Gb', 'Tb', 'Pb', 'Eb',
-    'getsize', 'listdir', 'format', 'format_string', 'format_plural'
+    'getsize', 'listdir', 'format', 'format_string', 'format_plural', 'parse_string'
 ]
 
 # Python 3.x compat
@@ -442,6 +444,10 @@ prefix unit' for representation:
     def to_Byte(self):
         return Byte(self._byte_value / float(NIST_STEPS['Byte']))
 
+    # Properties
+    Bit = property(lambda s: s.to_Bit())
+    Byte = property(lambda s: s.to_Byte())
+
     ##################################################################
 
     def to_KiB(self):
@@ -456,6 +462,12 @@ prefix unit' for representation:
     def to_kb(self):
         return kb(bits=self._bit_value)
 
+    # Properties
+    KiB = property(lambda s: s.to_KiB())
+    Kib = property(lambda s: s.to_Kib())
+    kB = property(lambda s: s.to_kB())
+    kb = property(lambda s: s.to_kb())
+
     ##################################################################
 
     def to_MiB(self):
@@ -470,6 +482,12 @@ prefix unit' for representation:
     def to_Mb(self):
         return Mb(bits=self._bit_value)
 
+    # Properties
+    MiB = property(lambda s: s.to_MiB())
+    Mib = property(lambda s: s.to_Mib())
+    MB = property(lambda s: s.to_MB())
+    Mb = property(lambda s: s.to_Mb())
+
     ##################################################################
 
     def to_GiB(self):
@@ -484,6 +502,12 @@ prefix unit' for representation:
     def to_Gb(self):
         return Gb(bits=self._bit_value)
 
+    # Properties
+    GiB = property(lambda s: s.to_GiB())
+    Gib = property(lambda s: s.to_Gib())
+    GB = property(lambda s: s.to_GB())
+    Gb = property(lambda s: s.to_Gb())
+
     ##################################################################
 
     def to_TiB(self):
@@ -498,6 +522,12 @@ prefix unit' for representation:
     def to_Tb(self):
         return Tb(bits=self._bit_value)
 
+    # Properties
+    TiB = property(lambda s: s.to_TiB())
+    Tib = property(lambda s: s.to_Tib())
+    TB = property(lambda s: s.to_TB())
+    Tb = property(lambda s: s.to_Tb())
+
     ##################################################################
 
     def to_PiB(self):
@@ -512,6 +542,12 @@ prefix unit' for representation:
     def to_Pb(self):
         return Pb(bits=self._bit_value)
 
+    # Properties
+    PiB = property(lambda s: s.to_PiB())
+    Pib = property(lambda s: s.to_Pib())
+    PB = property(lambda s: s.to_PB())
+    Pb = property(lambda s: s.to_Pb())
+
     ##################################################################
 
     def to_EiB(self):
@@ -526,6 +562,12 @@ prefix unit' for representation:
     def to_Eb(self):
         return Eb(bits=self._bit_value)
 
+    # Properties
+    EiB = property(lambda s: s.to_EiB())
+    Eib = property(lambda s: s.to_Eib())
+    EB = property(lambda s: s.to_EB())
+    Eb = property(lambda s: s.to_Eb())
+
     ##################################################################
     # Rich comparison operations
     ##################################################################
@@ -1000,6 +1042,50 @@ def listdir(search_base, followlinks=False, filter='*',
                     yield (_return_path, getsize(_path, bestprefix=bestprefix, system=system))
 
 
+def parse_string(s):
+    """Parse a string with units and try to make a bitmath object out of
+it.
+
+String inputs may include whitespace characters between the value and
+the unit.
+    """
+    # Strings only please
+    if type(s) is not str:
+        raise ValueError("parse_string only accepts string inputs but a %s was given" %
+                         type(s))
+
+    # get the index of the first alphabetic character
+    try:
+        index = list(map(str.isalpha, s)).index(True)
+    except ValueError:
+        # If there's no alphabetic characters we won't be able to .index(True)
+        raise ValueError("No unit detected, can not parse string '%s' into a bitmath object" % s)
+
+    # split the string into the value and the unit
+    val, unit = s[:index], s[index:]
+
+    # see if the unit exists as a type in our namespace
+
+    if unit == "b":
+        unit_class = Bit
+    elif unit == "B":
+        unit_class = Byte
+    else:
+        if not (hasattr(sys.modules[__name__], unit)
+                and isinstance(getattr(sys.modules[__name__], unit), type)):
+            raise ValueError("The unit %s is not a valid bitmath unit" % unit)
+        unit_class = globals()[unit]
+
+    try:
+        val = float(val)
+    except ValueError:
+        raise
+    try:
+        return unit_class(val)
+    except:  # pragma: no cover
+        raise ValueError("Can't parse string %s into a bitmath object" % s)
+
+
 @contextlib.contextmanager
 def format(fmt_str=None, plural=False, bestprefix=False):
     """Context manager for printing bitmath instances.
@@ -1032,3 +1118,62 @@ using their current prefix unit.
 
     if fmt_str:
         bitmath.format_string = orig_fmt_str
+
+
+def cli_script_main(cli_args):
+    """
+    A command line interface to basic bitmath operations.
+    """
+    import argparse
+
+    choices = ['Bit', 'Byte', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'kB',
+               'MB', 'GB', 'TB', 'PB', 'EB', 'Kib', 'Mib', 'Gib', 'Tib',
+               'Pib', 'Eib', 'kb', 'Mb', 'Gb', 'Tb', 'Pb', 'Eb']
+
+    parser = argparse.ArgumentParser(
+        description='Converts from one type of size to another.')
+    parser.add_argument('--from-stdin', default=False, action='store_true',
+                        help='Reads number from stdin rather than the cli')
+    parser.add_argument(
+        '-f', '--from', choices=choices, nargs=1,
+        type=str, dest='fromunit', default=['Byte'],
+        help='Input type you are converting from. Defaultes to Byte.')
+    parser.add_argument(
+        '-t', '--to', choices=choices, required=False, nargs=1, type=str,
+        help=('Input type you are converting to. '
+              'Attempts to detect best result if omitted.'), dest='tounit')
+    parser.add_argument(
+        'size', nargs='*', type=float,
+        help='The number to convert.')
+
+    args = parser.parse_args(cli_args)
+
+    if args.from_stdin:
+        args.size = [float(sys.stdin.readline()[:-1])]
+
+    results = []
+
+    for size in args.size:
+        instance = getattr(__import__(
+            'bitmath', fromlist=['True']), args.fromunit[0])(size)
+
+        # If we have a unit provided then use it
+        if args.tounit:
+            result = getattr(instance, args.tounit[0])
+        # Otherwise use the best_prefix call
+        else:
+            result = instance.best_prefix()
+
+        results.append(result)
+
+    return results
+
+
+def cli_script():  # pragma: no cover
+    # Wrapper around cli_script_main so we can unittest the command
+    # line functionality
+    for result in cli_script_main(sys.argv):
+        print(result)
+
+if __name__ == '__main__':
+    cli_script()
