@@ -56,6 +56,7 @@ class TestToTypeConversion(TestCase):
         """bitmath type converted to the same unit is properly converted"""
         to_kib = self.kib.to_KiB()
         self.assertIs(type(to_kib), bitmath.KiB)
+        self.assertIs(type(self.kib.KiB), bitmath.KiB)
 
     def test_from_other(self):
         """MiB object from_other object"""
@@ -67,10 +68,12 @@ class TestToTypeConversion(TestCase):
     def test_to_Bit(self):
         """Convert to Bit"""
         self.assertIs(type(self.kb.to_Bit()), bitmath.Bit)
+        self.assertIs(type(self.kb.Bit), bitmath.Bit)
 
     def test_to_Byte(self):
         """Convert to Byte"""
         self.assertIs(type(self.kb.to_Byte()), bitmath.Byte)
+        self.assertIs(type(self.kb.Byte), bitmath.Byte)
 
     ##################################################################
     # to k's
@@ -78,16 +81,19 @@ class TestToTypeConversion(TestCase):
         """Convert to KiB"""
         to_kib = self.mib.to_KiB()
         self.assertIs(type(to_kib), bitmath.KiB)
+        self.assertIs(type(self.mib.KiB), bitmath.KiB)
 
     def test_to_Kib(self):
         """Convert to Kib"""
         to_kib = self.mib.to_Kib()
         self.assertIs(type(to_kib), bitmath.Kib)
+        self.assertIs(type(self.mib.Kib), bitmath.Kib)
 
     def test_to_kb(self):
         """Convert to kb"""
         to_kb = self.mib.to_kb()
         self.assertIs(type(to_kb), bitmath.kb)
+        self.assertIs(type(self.mib.kb), bitmath.kb)
 
     ##################################################################
     # to m's
@@ -95,21 +101,25 @@ class TestToTypeConversion(TestCase):
         """Convert a bitmath GiB into a MiB"""
         to_mib = self.gib.to_MiB()
         self.assertIs(type(to_mib), bitmath.MiB)
+        self.assertIs(type(self.gib.MiB), bitmath.MiB)
 
     def test_to_Mib(self):
         """Convert a bitmath GiB into a Mib"""
         to_mib = self.gib.to_Mib()
         self.assertIs(type(to_mib), bitmath.Mib)
+        self.assertIs(type(self.gib.Mib), bitmath.Mib)
 
     def test_to_MB(self):
         """Convert a bitmath GiB into a MB"""
         to_mb = self.gib.to_MB()
         self.assertIs(type(to_mb), bitmath.MB)
+        self.assertIs(type(self.gib.MB), bitmath.MB)
 
     def test_to_Mb(self):
         """Convert a bitmath GiB into a Mb"""
         to_mb = self.gib.to_Mb()
         self.assertIs(type(to_mb), bitmath.Mb)
+        self.assertIs(type(self.gib.Mb), bitmath.Mb)
 
     ##################################################################
     # to g's
@@ -117,21 +127,25 @@ class TestToTypeConversion(TestCase):
         """Convert a bitmath TiB into a GiB"""
         to_gib = self.tib.to_GiB()
         self.assertIs(type(to_gib), bitmath.GiB)
+        self.assertIs(type(self.tib.GiB), bitmath.GiB)
 
     def test_to_Gib(self):
         """Convert a bitmath GiB into a Gib"""
         to_gib = self.gib.to_Gib()
         self.assertIs(type(to_gib), bitmath.Gib)
+        self.assertIs(type(self.tib.Gib), bitmath.Gib)
 
     def test_to_GB(self):
         """Convert a bitmath GiB into a GB"""
         to_gb = self.gib.to_GB()
         self.assertIs(type(to_gb), bitmath.GB)
+        self.assertIs(type(self.tib.GB), bitmath.GB)
 
     def test_to_Gb(self):
         """Convert a bitmath GiB into a Gb"""
         to_gb = self.gib.to_Gb()
         self.assertIs(type(to_gb), bitmath.Gb)
+        self.assertIs(type(self.tib.Gb), bitmath.Gb)
 
     ##################################################################
     # to t's
@@ -139,21 +153,25 @@ class TestToTypeConversion(TestCase):
         """Convert a bitmath PiB into a TiB"""
         to_tib = self.pib.to_TiB()
         self.assertIs(type(to_tib), bitmath.TiB)
+        self.assertIs(type(self.pib.TiB), bitmath.TiB)
 
     def test_to_Tib(self):
         """Convert a bitmath GiB into a Tib"""
         to_tib = self.gib.to_Tib()
         self.assertIs(type(to_tib), bitmath.Tib)
+        self.assertIs(type(self.pib.Tib), bitmath.Tib)
 
     def test_to_TB(self):
         """Convert a bitmath GiB into a TB"""
         to_tb = self.gib.to_TB()
         self.assertIs(type(to_tb), bitmath.TB)
+        self.assertIs(type(self.pib.TB), bitmath.TB)
 
     def test_to_Tb(self):
         """Convert a bitmath GiB into a Tb"""
         to_tb = self.gib.to_Tb()
         self.assertIs(type(to_tb), bitmath.Tb)
+        self.assertIs(type(self.pib.Tb), bitmath.Tb)
 
     ##################################################################
     # to p's
@@ -161,21 +179,25 @@ class TestToTypeConversion(TestCase):
         """Convert a bitmath TiB into a PiB"""
         to_pib = self.tib.to_PiB()
         self.assertIs(type(to_pib), bitmath.PiB)
+        self.assertIs(type(self.tib.PiB), bitmath.PiB)
 
     def test_to_Pib(self):
         """Convert a bitmath GiB into a PiB"""
         to_pib = self.gib.to_Pib()
         self.assertIs(type(to_pib), bitmath.Pib)
+        self.assertIs(type(self.gib.Pib), bitmath.Pib)
 
     def test_to_PB(self):
         """Convert a bitmath GiB into a PB"""
         to_pb = self.gib.to_PB()
         self.assertIs(type(to_pb), bitmath.PB)
+        self.assertIs(type(self.gib.PB), bitmath.PB)
 
     def test_to_Pb(self):
         """Convert a bitmath GiB into a Pb"""
         to_pb = self.gib.to_Pb()
         self.assertIs(type(to_pb), bitmath.Pb)
+        self.assertIs(type(self.gib.Pb), bitmath.Pb)
 
     ##################################################################
     # to e's
@@ -183,21 +205,25 @@ class TestToTypeConversion(TestCase):
         """Convert a bitmath PiB into a EiB"""
         to_eib = self.pib.to_EiB()
         self.assertIs(type(to_eib), bitmath.EiB)
+        self.assertIs(type(self.pib.EiB), bitmath.EiB)
 
     def test_to_Eib(self):
         """Convert a bitmath GiB into a Eib"""
         to_eib = self.gib.to_Eib()
         self.assertIs(type(to_eib), bitmath.Eib)
+        self.assertIs(type(self.pib.Eib), bitmath.Eib)
 
     def test_to_EB(self):
         """Convert a bitmath GiB into a EB"""
         to_eb = self.gib.to_EB()
         self.assertIs(type(to_eb), bitmath.EB)
+        self.assertIs(type(self.pib.EB), bitmath.EB)
 
     def test_to_Eb(self):
         """Convert a bitmath GiB into a Eb"""
         to_eb = self.gib.to_Eb()
         self.assertIs(type(to_eb), bitmath.Eb)
+        self.assertIs(type(self.pib.Eb), bitmath.Eb)
 
     ##################################################################
     # to other stuff
